@@ -14,7 +14,6 @@ def get_stats(data, np_stats=['max', 'min', 'mean', 'std']):
     Returns:
         dictionary: dict of the stats names as keys and values associated with np_stats
     '''
-    log = get_logger(__name__)
 
     # put together the operations to use
     operations = np_stats
@@ -22,10 +21,7 @@ def get_stats(data, np_stats=['max', 'min', 'mean', 'std']):
     # Build the output
     out = OrderedDict()
 
-    log.info('Data is {}'.format(' X '.join([str(s) for s in data.shape])))
-
     for op in operations:
-        log.info('Calculating {} ...'.format(op))
         stat_fn = getattr(data, op)
         out[op] = stat_fn()
 
